@@ -620,7 +620,7 @@ def summary_legacy(shap_values, features=None, feature_names=None, max_display=N
     elif plot_size is not None:
         pl.gcf().set_size_inches(8, len(feature_order) * plot_size + 1.5)
     pl.axvline(x=0, color="#999999", zorder=-1)
-    pl.rcParams['font.sans-serif'] = ['SimSun']
+    # pl.rcParams['font.sans-serif'] = ['SimSun']
 
     if plot_type == "dot":
         for pos, i in enumerate(feature_order):
