@@ -94,7 +94,7 @@ def waterfall(shap_values, max_display=10, show=True):
     
     # size the plot based on how many features we are plotting
     pl.gcf().set_size_inches(8, num_features * row_height + 1.5)
-    pl.rcParams['font.sans-serif'] = ['SimSun']
+    # pl.rcParams['font.sans-serif'] = ['SimSun']
 
     # see how many individual (vs. grouped at the end) features we are plotting
     if num_features == len(values):
@@ -298,7 +298,7 @@ def waterfall(shap_values, max_display=10, show=True):
 
 
 
-def waterfall_legacy(expected_value, shap_values=None, features=None, feature_names=None, max_display=10, show=True):
+def waterfall_legacy(base_value, shap_values=None, features=None, feature_names=None, max_display=10, show=True):
     """ Plots an explantion of a single prediction as a waterfall plot.
 
     The SHAP value of a feature represents the impact of the evidence provided by that feature on the model's
@@ -335,6 +335,7 @@ def waterfall_legacy(expected_value, shap_values=None, features=None, feature_na
     # support passing an explanation object
     upper_bounds = None
     lower_bounds = None
+    expected_value=base_value
     if str(type(expected_value)).endswith("Explanation'>"):
         shap_exp = expected_value
         expected_value = shap_exp.expected_value
@@ -386,7 +387,7 @@ def waterfall_legacy(expected_value, shap_values=None, features=None, feature_na
     
     # size the plot based on how many features we are plotting
     pl.gcf().set_size_inches(8, num_features * row_height + 1.5)
-    pl.rcParams['font.sans-serif'] = ['SimSun']
+    # pl.rcParams['font.sans-serif'] = ['SimSun']
 
     # see how many individual (vs. grouped at the end) features we are plotting
     if num_features == len(shap_values):
